from setuptools import setup

setup(
    name='ansible-apply',
    versioning='post',
    url='https://yourlabs.io/oss/ansible-apply',
    setup_requires='setupmeta',
    keywords='automation cli',
    python_requires='>=3',
    include_package_data=True,
)
